<?php

namespace Drupal\hidden_nodes\Form;

use Drupal;
use Drupal\Component\Utility\Html;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

class HiddenNodesAdminForm extends ConfigFormBase {

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form =  parent::buildForm($form, $form_state);
    $config = $this->config('hidden_nodes.settings');

    $priorities = array(
      0 => 0,
      10 => 10,
      100 => 100,
      1000 => 1000
    );
    $form['hidden_nodes_priority'] = array(
      '#type' => 'select',
      '#options' => $priorities,
      '#title' => t('Node Grants Priority'),
      '#description' => t("Priority to give hidden nodes in the granting of permissions, set this to 0 to avoid conflicts with other projects (like TAC). 1000 is the default in order to take priority over all other grant methods."),
      '#default_value' => $config->get('hidden_nodes_priority'),
    );
    foreach (NodeType::loadMultiple() as $type_data) {
      $types[$type_data->id()] = $type_data->label();
    }
    $form['hidden_nodes_types'] = array(
      '#type' => 'select',
      '#options' => $types,
      '#title' => t('Types to hide'),
      '#description' => t("Select the content types that are allowed to be hidden."),
      '#default_value' => $config->get('hidden_nodes_types'),
      '#multiple' => TRUE,
    );

    $form['hidden_nodes_apply_styles'] = array(
      '#type' => 'checkbox',
      '#title' => t("Use this module's styles for hidden content and menu links to hidden content."),
      '#description' => t("Apply the CSS rules supplied with this module.  Note: these rules may not affect display if overridden in theme."),
      '#default_value' => $config->get('hidden_nodes_apply_styles'),
    );

    $form['content'] = array(
      '#type' => 'fieldset',
      '#title' => t('Hidden full node message'),
    );
    $form['content']['hidden_nodes_show_message'] = array(
      '#type' => 'checkbox',
      '#title' => t("Display a message if the current content is hidden."),
      '#description' => t("A message will be displayed when viewing full nodes that are hidden."),
      '#default_value' => $config->get('hidden_nodes_show_message'),
    );
    $form['content']['hidden_nodes_message'] = array(
      '#type' => 'textfield',
      '#title' => t('Message'),
      '#default_value' => HTML::escape($config->get('hidden_nodes_message')),
      '#size' => 90,
      '#maxlength' => 128,
    );

    $form['partial_content'] = array(
      '#type' => 'fieldset',
      '#title' => t('Hidden partial content message'),
    );
    $form['partial_content']['hidden_nodes_show_partial_message'] = array(
      '#type' => 'checkbox',
      '#title' => t("Display message if some of a page's content is hidden."),
      '#description' => t("A message will be displayed when viewing pages where only some of a page's content may be hidden, such as Views containing hidden content."),
      '#default_value' => $config->get('hidden_nodes_show_partial_message'),
    );
    $form['partial_content']['hidden_nodes_partial_message'] = array(
      '#type' => 'textfield',
      '#title' => t('Message'),
      '#default_value' => HTML::escape($config->get('hidden_nodes_partial_message')),
      '#size' => 90,
      '#maxlength' => 128,
    );

    $form['parent_content'] = array(
      '#type' => 'fieldset',
      '#title' => t('Hidden parent content message'),
    );
    $form['parent_content']['hidden_nodes_show_parent_message'] = array(
      '#type' => 'checkbox',
      '#title' => t("Display a message if Book content has some parent content that is hidden."),
      '#description' => t("A message will be displayed for Book content that has hidden parent content."),
      '#default_value' => $config->get('hidden_nodes_show_parent_message'),
    );
    $form['parent_content']['hidden_nodes_parent_message'] = array(
      '#type' => 'textfield',
      '#title' => t('Message'),
      '#default_value' => HTML::escape($config->get('hidden_nodes_parent_message')),
      '#size' => 90,
      '#maxlength' => 128,
    );

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = Drupal::service('config.factory')->getEditable('hidden_nodes.settings');
    \Drupal::logger('Submit')->info('<pre><code>' . print_r($form_state->getValues(), TRUE) . '</code></pre>');
    $config
      ->set('hidden_nodes_types', $form_state->getValue('hidden_nodes_types'))
      ->set('hidden_nodes_priority', $form_state->getValue('hidden_nodes_priority'))
      ->set('hidden_nodes_apply_styles', $form_state->getValue('hidden_nodes_apply_styles'))
      ->set('hidden_nodes_show_message', $form_state->getValue('hidden_nodes_show_message'))
      ->set('hidden_nodes_message', $form_state->getValue('hidden_nodes_message'))
      ->set('hidden_nodes_show_partial_message', $form_state->getValue('hidden_nodes_show_partial_message'))
      ->set('hidden_nodes_partial_message', $form_state->getValue('hidden_nodes_partial_message'))
      ->set('hidden_nodes_show_parent_message', $form_state->getValue('hidden_nodes_show_parent_message'))
      ->set('hidden_nodes_parent_message', $form_state->getValue('hidden_nodes_parent_message'))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  protected function getEditableConfigNames() {
    return [
      'hidden_nodes.settings',
    ];
  }

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'hidden_nodes_form';
  }

}
