<?php

namespace Drupal\hidden_nodes\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\OpenModalDialogCommand;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\Node;

class HiddenNodesModalForm extends FormBase {
  public function buildForm(array $form, FormStateInterface $form_state, $arg = NULL) {
    $current_user = \Drupal::currentUser();
    $node = Node::load($arg['node']);
    $form_state->set('node', $node);
    $form['#prefix'] = '<div id="hidden_node_book_form">';
    $form['#suffix'] = '</div>';


    $form['hidden'] = [
      '#type' => 'checkbox',
      '#title' => t('Hide this content'),
      '#default_value' => $node->isHidden,
      '#access' => $current_user->hasPermission('view hidden content'),
    ];
    $form['propagate'] = [
      '#type' => 'checkbox',
      '#title' => t('Propagate hidden status'),
      '#access' => $current_user->hasPermission('view hidden content'),
    ];

    $form['actions'] = array('#type' => 'actions');
    $form['actions']['send'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit modal form'),
      '#attributes' => [
        'class' => [
          'use-ajax',
        ],
      ],
      '#ajax' => [
        'callback' => [$this, 'submitModalFormAjax'],
        'event' => 'click',
      ],
    ];

    $form['#attached']['library'][] = 'core/drupal.dialog.ajax';

    return $form;
  }

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'hidden_nodes_modal_form';
  }

  /**
   * @inheritDoc
   */
  public function submitModalFormAjax(array &$form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    $node = $form_state->get('node');
    $status = $form_state->getValue('hidden');
    $node->isHidden = $status;

    // Call our module function for updating hidden_node table.
    _hidden_node_hidden_value_update($node);

    // Even though we are not modifying node fields we need to run save() to
    // fire the proper hooks to reset the permissions on the node.
    $node->save();

    // If we are propagating hidden node value to the children of the node.
    $check_status = $form_state->getValue('propagate');
    if ($check_status == 1) {
      try {
        hidden_nodes_propagate_hide_node($node->id(), $status);
      } catch (EntityStorageException $e) {
        \Drupal::logger('Hidden Nodes')->error('Could not propagate hidden node status to all nodes: @e', array('@e' => $e));
      }
    }

    // If there are any form errors, re-display the form.
    if ($form_state->hasAnyErrors()) {
      $response->addCommand(new ReplaceCommand('#hidden_node_book_form', $form));
    }
    else {
      $response->addCommand(new OpenModalDialogCommand("Success!", 'Your hidden node statuses have been updated.', ['width' => 800]));
    }

    return $response;
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {}

  public function submitForm(array &$form, FormStateInterface $form_state) {}
}
